@@ -1,37 +1,45 @@
 from __future__ import annotations
 
-import asyncio
-from typing import List, Optional, TYPE_CHECKING
+from typing import List, Optional
 
-from mi.api.favorite import FavoriteManager
-from mi.api.reaction import ReactionManager
 from mi.exception import ContentRequired
-from mi.http import HTTPClient, Route
-from mi.models.note import RawNote
-from mi.note import Note, NoteReaction, Poll
+from mi.framework.http import HTTPSession, Route
+from mi.framework.models.note import Note, NoteReaction, Poll
 from mi.utils import check_multi_arg, remove_dict_empty
-
-if TYPE_CHECKING:
-    from mi.state import ConnectionState
+from mi.wrapper.favorite import FavoriteManager
+from mi.wrapper.models.note import RawNote
+from mi.wrapper.reaction import ReactionManager
 
 __all__ = ['NoteActions']
 
 
 class NoteActions:
-    def __init__(self, state: 'ConnectionState', http: HTTPClient, loop: asyncio.AbstractEventLoop,
-                 note_id: Optional[str] = None):
-        self.__state = state
-        self.__http = http
-        self.__loop = loop
+    def __init__(self, note_id: Optional[str] = None):
         self.__note_id: Optional[str] = note_id
-        self.favorite = FavoriteManager(state, http, loop, note_id=note_id)
-        self.reaction = ReactionManager(state, http, loop, note_id=note_id)
+        self.favorite = FavoriteManager(note_id=note_id)
+        self.reaction = ReactionManager(note_id=note_id)
 
     async def add_clips(self, clip_id: str, note_id: Optional[str] = None) -> bool:
+        """
+        クリップに追加します
+
+        Parameters
+        ----------
+        clip_id : str
+            クリップのID
+        note_id Optional[str], default=None
+            追加したいノートのID
+
+        Returns
+        -------
+        bool
+            成功したか否か
+        """
+
         note_id = note_id or self.__note_id
 
         data = {'noteId': note_id, 'clipId': clip_id}
-        return bool(await self.__http.request(Route('POST', '/api/clips/add-note'), json=data, auth=True))
+        return bool(await HTTPSession.request(Route('POST', '/api/clips/add-note'), json=data, auth=True))
 
     async def send(self,
                    content: Optional[str] = None,
@@ -121,17 +129,44 @@ class NoteActions:
         if file_ids:
             field["fileIds"] = file_ids
         field = remove_dict_empty(field)
-        res = await self.__http.request(Route('POST', '/api/notes/create'), json=field, auth=True, lower=True)
-        return Note(RawNote(res["created_note"]), state=self.__state)
+        res = await HTTPSession.request(Route('POST', '/api/notes/create'), json=field, auth=True, lower=True)
+        return Note(RawNote(res["created_note"]))
+
+    async def delete(self, note_id: Optional[str] = None) -> bool:
+        """
+        ノートを削除します
+
+        Parameters
+        ----------
+        note_id : Optional[str], default=None
+            削除したいノートのID
+
+        Returns
+        -------
+        bool
+            削除に成功したか否か
+        """
 
-    async def delete(self, note_id: Optional[str] = None):
         note_id = note_id or self.__note_id
 
         data = {"noteId": note_id}
-        res = await self.__http.request(Route('POST', '/api/notes/delete'), json=data, auth=True)
+        res = await HTTPSession.request(Route('POST', '/api/notes/delete'), json=data, auth=True)
         return bool(res)
 
     async def create_renote(self, note_id: Optional[str] = None) -> Note:
+        """
+        リノートを作成します
+
+        Parameters
+        ----------
+        note_id : Optional[str], default=None
+            ノートのID
+
+        Returns
+        -------
+        Note
+            作成したリノート
+        """
         note_id = note_id or self.__note_id
         return await self.send(renote_id=note_id)
 
@@ -186,9 +221,22 @@ class NoteActions:
                                extract_emojis=extract_emojis, renote_id=note_id, file_ids=file_ids, poll=poll)
 
     async def get_note(self, note_id: Optional[str] = None) -> Note:
+        """
+        ノートを取得します
+
+        Parameters
+        ----------
+        note_id : Optional[str], default=None
+            ノートのID
+
+        Returns
+        -------
+        Note
+            取得したノートID
+        """
         note_id = note_id or self.__note_id
-        res = await self.__http.request(Route('POST', '/api/notes/show'), json={"noteId": note_id}, auth=True, lower=True)
-        return Note(RawNote(res), state=self.__state)
+        res = await HTTPSession.request(Route('POST', '/api/notes/show'), json={"noteId": note_id}, auth=True, lower=True)
+        return Note(RawNote(res))
 
     async def get_replies(
             self,
@@ -197,12 +245,31 @@ class NoteActions:
             limit: int = 10,
             note_id: Optional[str] = None
     ) -> List[Note]:
+        """
+        ノートに対する返信を取得します
+
+        Parameters
+        ---------
+        since_id : Optional[str], default=None
+            指定すると、その投稿を投稿を起点としてより新しい投稿を取得します
+        until_id : Optional[str], default=None
+            指定すると、その投稿を投稿を起点としてより古い投稿を取得します
+        limit : int, default=10
+            取得する上限
+        note_id: Optional[str], default=None
+            返信を取得したいノートのID
+
+        Returns
+        -------
+        List[Note]
+            返信のリスト
+        """
         note_id = note_id or self.__note_id
-        res = await self.__http.request(Route('POST', '/api/notes/replies'),
+        res = await HTTPSession.request(Route('POST', '/api/notes/replies'),
                                         json={"noteId": note_id, "sinceId": since_id, "untilId": until_id, "limit": limit},
                                         auth=True, lower=True)
-        return [Note(RawNote(i), state=self.__state) for i in res]
+        return [Note(RawNote(i)) for i in res]
 
     async def get_reaction(self, reaction: str, note_id: Optional[str] = None) -> List[NoteReaction]:
         note_id = note_id or self.__note_id
-        return await ReactionManager(self.__state, self.__http, self.__loop, note_id=note_id).get_reaction(reaction)
+        return await ReactionManager(note_id=note_id).get_reaction(reaction)
