@@ -19,10 +19,17 @@ __all__ = (
     "InternalServerError",
     "TaskNotRunningError",
     "NotFoundError",
-    "NotExistRequiredData"
+    "NotExistRequiredData",
+    "NotSupportedError"
 )
 
 
+class NotSupportedError(Exception):
+    """
+    is_ayuskeyをTrueにしていて、かつサポートされていないAPIをを使用した際に発生する例外
+    """
+
+
 class NotExistRequiredData(Exception):
     """
     必要なデータが存在しない場合に発生する例外
